/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
import { PostfachE2EComponent } from '../../../components/postfach/postfach.e2e.component';
import { waitForSpinnerToDisappear } from '../../../page-objects/main.po';
import { exist } from '../../../support/cypress.util';
import { loginAsAriane } from '../../../support/user-util';

describe('Signatur', () => {
  const postfach: PostfachE2EComponent = new PostfachE2EComponent();

  const signaturText: string = 'Signatur\nmit\n\n\n\nZeilenumbruch\n\n';

  before(() => {
    loginAsAriane();
  });

  it('should show Postfach page', () => {
    waitForSpinnerToDisappear();
    exist(postfach.getSignaturText());
  });

  it('should show signature input with scrollbar', () => {
    postfach.setSignatur(signaturText);
    postfach.saveSignatur();

    postfach.signatureIs(signaturText);
    postfach.scrollbarIsPresent();
  });

  it('should enter an save empty signature', () => {
    postfach.clearSignatur();
    postfach.saveSignatur();

    postfach.signatureIs('');
  });
});
