/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
import {
  dispatchEventFromFixture,
  getElementFromFixture,
  mock,
  Mock,
} from '@alfa-client/test-utils';
import { ComponentFixture, TestBed } from '@angular/core/testing';
import { RouterTestingModule } from '@angular/router/testing';
import {
  DropdownMenuButtonComponent,
  DropdownMenuComponent,
  LogoutIconComponent,
} from '@ods/system';
import { AuthenticationService } from 'authentication';
import { getDataTestIdOf } from 'libs/tech-shared/test/data-test';
import { MockComponent } from 'ng-mocks';
import { UserProfileButtonContainerComponent } from './user-profile.button-container.component';

describe('UserProfileButtonContainerComponent', () => {
  let component: UserProfileButtonContainerComponent;
  let fixture: ComponentFixture<UserProfileButtonContainerComponent>;

  const authenticationService: Mock<AuthenticationService> = mock(AuthenticationService);

  const popupButtonContent: string = getDataTestIdOf('popup-button-content');
  const popupLogoutButton: string = getDataTestIdOf('popup-logout-button');

  beforeEach(async () => {
    await TestBed.configureTestingModule({
      declarations: [UserProfileButtonContainerComponent],
      imports: [
        RouterTestingModule,
        MockComponent(DropdownMenuComponent),
        MockComponent(DropdownMenuButtonComponent),
        MockComponent(LogoutIconComponent),
      ],
      providers: [
        {
          provide: AuthenticationService,
          useValue: authenticationService,
        },
      ],
    }).compileComponents();
  });

  beforeEach(() => {
    fixture = TestBed.createComponent(UserProfileButtonContainerComponent);
    component = fixture.componentInstance;
    fixture.detectChanges();
  });

  it('should create', () => {
    expect(component).toBeTruthy();
  });

  describe('ngOnInit', () => {
    it('should call authService to get current user initials', () => {
      component.ngOnInit();

      expect(authenticationService.getCurrentUserInitials).toHaveBeenCalled();
    });
  });

  describe('popup button', () => {
    it('should show initials', () => {
      component.currentUserInitials = 'AV';
      fixture.detectChanges();

      const popupButtonContentElement: HTMLElement = getElementFromFixture(
        fixture,
        popupButtonContent,
      );

      expect(popupButtonContentElement.textContent.trim()).toEqual('AV');
    });
  });

  describe('logout', () => {
    it('should call authService logout', () => {
      dispatchEventFromFixture(fixture, popupLogoutButton, 'itemClicked');

      expect(authenticationService.logout).toHaveBeenCalled();
    });
  });
});
