/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
import { UsersRolesComponent } from '@admin-client/admin-settings';
import { getEnvironmentFactory } from '@alfa-client/environment-shared';
import { existsAsHtmlElement, notExistsAsHtmlElement } from '@alfa-client/test-utils';
import { ComponentFixture, TestBed } from '@angular/core/testing';
import { createEnvironment } from 'libs/environment-shared/test/environment';
import { getDataTestIdOf } from 'libs/tech-shared/test/data-test';
import { MockComponent } from 'ng-mocks';
import { UserRolesPageComponent } from './user-roles-page.component';

jest.mock('@alfa-client/environment-shared');

describe('UserRolesPageComponent', () => {
  let component: UserRolesPageComponent;
  let fixture: ComponentFixture<UserRolesPageComponent>;

  const usersRolesSelector: string = getDataTestIdOf('users-roles');

  const environment = createEnvironment();
  (getEnvironmentFactory as jest.Mock).mockReturnValue(environment);

  beforeEach(async () => {
    await TestBed.configureTestingModule({
      declarations: [UserRolesPageComponent],
      imports: [MockComponent(UsersRolesComponent)],
    }).compileComponents();

    fixture = TestBed.createComponent(UserRolesPageComponent);
    component = fixture.componentInstance;
    fixture.detectChanges();
  });

  it('should create', () => {
    expect(component).toBeTruthy();
  });

  describe('template', () => {
    describe('admin-users-roles', () => {
      it('should be rendered if feature toggle benutzerRollen is true', () => {
        environment.features.benutzerRollen = true;
        fixture.detectChanges();

        existsAsHtmlElement(fixture, usersRolesSelector);
      });

      it('should not be rendered component if feature toggle benutzerRollen is false', () => {
        environment.features.benutzerRollen = false;
        fixture.detectChanges();

        notExistsAsHtmlElement(fixture, usersRolesSelector);
      });
    });
  });
});
