/*
 * Copyright (C) 2023 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
import { InternalServerErrorDialogE2EComponent } from '../../../components/ui/internal-server-error-diaog.e2e.component';
import { VorgangListE2EComponent } from '../../../components/vorgang/vorgang-list.e2e.component';
import { HttpMethodE2E } from '../../../model/util';
import { VorgangE2E } from '../../../model/vorgang';
import { MainPage, waitForSpinnerToDisappear } from '../../../page-objects/main.po';
import {
  dropCollections,
  interceptWithResponse,
  waitOfInterceptor,
} from '../../../support/cypress-helper';
import { contains, exist } from '../../../support/cypress.util';
import { MessagesE2E } from '../../../support/messages';
import { loginAsSabine } from '../../../support/user-util';
import { createVorgang, initVorgang } from '../../../support/vorgang-util';

describe('Interceptor Server Error', () => {
  const mainPage: MainPage = new MainPage();
  const vorgangList: VorgangListE2EComponent = mainPage.getVorgangList();
  const errorDialog: InternalServerErrorDialogE2EComponent =
    mainPage.getInternalServerErrorDialog();

  const vorgang: VorgangE2E = createVorgang();

  before(() => {
    initVorgang(vorgang);

    loginAsSabine();

    waitForSpinnerToDisappear();
    exist(vorgangList.getRoot());
  });

  after(() => {
    dropCollections();
  });

  describe('click on vorgang', () => {
    const statusCode: number = 500;
    const interceptor: string = 'getVorgang';

    beforeEach(() => {
      const url: string = '*/vorgangs/' + vorgang._id.$oid;

      interceptWithResponse(HttpMethodE2E.GET, url, { statusCode }).as(interceptor);
    });

    it('should show page', () => {
      vorgangList.getListItem(vorgang.name).getRoot().click();

      waitOfInterceptor(interceptor).then((interception) => {
        assert(interception.response.statusCode, statusCode.toString());
        contains(errorDialog.getHeader(), MessagesE2E.HTTP_SERVER_ERROR_DIALOG_HEADER);
        exist(errorDialog.getIcon());
        contains(errorDialog.getMessage(), MessagesE2E.HTTP_SERVER_ERROR);
        exist(errorDialog.getLogoutButton());
      });
    });
  });
});
