/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
import {
  PostfachMailE2EComponent,
  PostfachMailListItem,
} from 'apps/alfa-e2e/src/components/postfach/postfach-mail.e2e.component';
import { VorgangSubnavigationE2EComponent } from 'apps/alfa-e2e/src/components/vorgang/vorgang-subnavigation';
import {
  VorgangViewE2EComponent,
  VorgangViewsE2EComponent,
} from 'apps/alfa-e2e/src/components/vorgang/vorgang-views.e2e.component';
import {
  PostfachMailItemE2E,
  VorgangAttachedItemClientE2E,
  VorgangAttachedItemE2E,
} from 'apps/alfa-e2e/src/model/vorgang-attached-item';
import { VorgangPage } from 'apps/alfa-e2e/src/page-objects/vorgang.po';
import { exist, haveLength } from 'apps/alfa-e2e/src/support/cypress.util';
import {
  createPostfachNachrichtAttachedItem,
  createPostfachNachrichtReplyItem,
  initVorgangAttachedItem,
} from 'apps/alfa-e2e/src/support/vorgang-attached-item-util';
import { VorgangListE2EComponent } from '../../../components/vorgang/vorgang-list.e2e.component';
import { ClientAttributeNameE2E, ClientAttributesE2E, VorgangE2E } from '../../../model/vorgang';
import { MainPage, waitForSpinnerToDisappear } from '../../../page-objects/main.po';
import { dropCollections } from '../../../support/cypress-helper';
import { initUsermanagerUsers, loginAsSabine } from '../../../support/user-util';
import {
  buildVorgang,
  createHasNewPostfachNachrichtClientAttribute,
  createHasPostfachNachrichtClientAttribute,
  initVorgaenge,
  objectIds,
} from '../../../support/vorgang-util';

describe('VorgangList Ungelesene Nachrichten', () => {
  const mainPage: MainPage = new MainPage();
  const vorgangList: VorgangListE2EComponent = mainPage.getVorgangList();
  const vorgangPage: VorgangPage = new VorgangPage();
  const subnavigation: VorgangSubnavigationE2EComponent = vorgangPage.getSubnavigation();
  const views: VorgangViewsE2EComponent = mainPage.getViews();
  const ungelesenView: VorgangViewE2EComponent = views.getUngelesen();
  const postfachMailContainer: PostfachMailE2EComponent = vorgangPage.getPostfachMailcontainer();

  const clientAttributes: ClientAttributesE2E = {
    [VorgangAttachedItemClientE2E.OZGCLOUD_NACHRICHTEN_MANAGER]: {
      [ClientAttributeNameE2E.HAS_NEW_POSTFACH_NACHRICHT]:
        createHasNewPostfachNachrichtClientAttribute(true),
      [ClientAttributeNameE2E.HAS_POSTFACH_NACHRICHT]:
        createHasPostfachNachrichtClientAttribute(true),
    },
  };

  const vorgangWithReply1: VorgangE2E = {
    ...buildVorgang(objectIds[0], 'VorgangWithReply'),
    clientAttributes,
  };

  const vorgangWithReply2: VorgangE2E = {
    ...buildVorgang(objectIds[1], 'VorgangWithReply 2'),
    clientAttributes,
  };

  const postfachMailReply1: PostfachMailItemE2E = createPostfachNachrichtReplyItem();
  const postfachMailReply2: PostfachMailItemE2E = createPostfachNachrichtReplyItem();

  const postfachNachrichtAttachedItem1: VorgangAttachedItemE2E = {
    ...createPostfachNachrichtAttachedItem(objectIds[0], vorgangWithReply1._id.$oid),
    item: postfachMailReply1,
  };
  const postfachNachrichtAttachedItem2: VorgangAttachedItemE2E = {
    ...createPostfachNachrichtAttachedItem(objectIds[1], vorgangWithReply2._id.$oid),
    item: postfachMailReply2,
  };

  before(() => {
    initVorgaenge([vorgangWithReply1, vorgangWithReply2]);
    initVorgangAttachedItem([postfachNachrichtAttachedItem1]);
    initVorgangAttachedItem([postfachNachrichtAttachedItem2]);
    initUsermanagerUsers();

    loginAsSabine();

    waitForSpinnerToDisappear();
    exist(vorgangList.getRoot());
  });

  after(() => {
    dropCollections();
  });

  describe('Show number of unread messages', () => {
    it('should show 2 unread messages in filter', () => {
      ungelesenView.getRoot().click();
      waitForSpinnerToDisappear();

      haveLength(vorgangList.getItems(), 2);
    });

    it('should show 1 unread message after viewing first message', () => {
      vorgangList.getListItem(vorgangWithReply1.name).getRoot().click();
      waitForSpinnerToDisappear();

      const postfachMailItem: PostfachMailListItem = postfachMailContainer.getListItem('Subject');
      postfachMailItem.getRoot().click();
      waitForSpinnerToDisappear();

      subnavigation.back();
      subnavigation.back();

      haveLength(vorgangList.getItems(), 1);
    });

    it('should show 0 unread messages after viewing second message', () => {
      vorgangList.getListItem(vorgangWithReply2.name).getRoot().click();
      waitForSpinnerToDisappear();

      const postfachMailItem: PostfachMailListItem = postfachMailContainer.getListItem('Subject');
      postfachMailItem.getRoot().click();
      waitForSpinnerToDisappear();

      subnavigation.back();
      subnavigation.back();

      haveLength(vorgangList.getItems(), 0);
    });
  });
});
