/*
 * Copyright (C) 2023 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
import { SnackBarE2EComponent } from 'apps/alfa-e2e/src/components/ui/snackbar.e2e.component';
import { VorgangDetailHeaderE2EComponent } from 'apps/alfa-e2e/src/components/vorgang/vorgang-detail-header.e2e.component';
import {
  VorgangViewE2EComponent,
  VorgangViewsE2EComponent,
} from 'apps/alfa-e2e/src/components/vorgang/vorgang-views.e2e.component';
import { VorgangAttachedItemE2E } from 'apps/alfa-e2e/src/model/vorgang-attached-item';
import { initVorgangAttachedItem } from 'apps/alfa-e2e/src/support/vorgang-attached-item-util';
import { WiedervorlageInVorgangE2EComponent } from '../../../components/wiedervorlage/wiedervorlage-in-vorgang.e2e.component';
import { WiedervorlageE2EComponent } from '../../../components/wiedervorlage/wiedervorlage-page.e2e.component';
import { WiedervorlageSubnavigationE2EComponent } from '../../../components/wiedervorlage/wiedervorlage-subnavigation';
import { WiedervorlagenInVorgangE2EComponent } from '../../../components/wiedervorlage/wiedervorlagen-in-vorgang.e2e.component';
import { ClientAttributeNameE2E, VorgangE2E } from '../../../model/vorgang';
import { WiedervorlageE2E } from '../../../model/wiedervorlage';
import {
  MainPage,
  waitForSpinnerToDisappear,
  waitforSpinnerToAppear,
} from '../../../page-objects/main.po';
import { VorgangPage } from '../../../page-objects/vorgang.po';
import { WiedervorlagePage } from '../../../page-objects/wiedervorlage.po';
import { dropCollections, wait } from '../../../support/cypress-helper';
import {
  containClass,
  contains,
  exist,
  notContainClass,
  notExist,
} from '../../../support/cypress.util';
import { loginAsSabine } from '../../../support/user-util';
import {
  createAlfaClientAttributes,
  createNextWiedervorlageFristClientAttribute,
  createVorgang,
  initVorgang,
  objectIds,
} from '../../../support/vorgang-util';
import {
  createWiedervorlageAttachedItem,
  createWiedervorlageItem,
} from '../../../support/wiedervorlage-util';

const wiedervorlageItemFixture: WiedervorlageE2E = require('../../../fixtures/wiedervorlage/wiedervorlage.json');

describe('Wiedervorlage erledigen/wiedereroeffnen', () => {
  const mainPage: MainPage = new MainPage();

  const views: VorgangViewsE2EComponent = mainPage.getViews();
  const wiedervorlagenView: VorgangViewE2EComponent = views.getWiedervorlagen();

  const snackBar: SnackBarE2EComponent = mainPage.getSnackBar();

  const vorgangPage: VorgangPage = new VorgangPage();
  const vorgangDetailHeader: VorgangDetailHeaderE2EComponent = vorgangPage.getVorgangDetailHeader();
  const wiedervorlageContainerInVorgang: WiedervorlagenInVorgangE2EComponent =
    vorgangPage.getWiedervorlagenContainer();

  const wiedervorlagePage: WiedervorlagePage = new WiedervorlagePage();
  const subnavigation: WiedervorlageSubnavigationE2EComponent =
    wiedervorlagePage.getSubnavigation();
  const wiedervorlageContainer: WiedervorlageE2EComponent =
    wiedervorlagePage.getWiedervorlageContainer();

  const vorgang: VorgangE2E = {
    ...createVorgang(),
    clientAttributes: createAlfaClientAttributes(
      ClientAttributeNameE2E.NEXT_WIEDERVORLAGE_FRIST,
      createNextWiedervorlageFristClientAttribute(wiedervorlageItemFixture.frist),
    ),
  };

  const wiedervorlageZumErledigen: WiedervorlageE2E = {
    ...createWiedervorlageItem('WiedervorlageZumErledigen'),
    done: false,
  };
  const wiedervorlageAttachedItemZumErledigen: VorgangAttachedItemE2E = {
    ...createWiedervorlageAttachedItem(objectIds[0], vorgang._id.$oid),
    item: wiedervorlageZumErledigen,
  };

  const wiedervorlageZumWiedereroeffnen: WiedervorlageE2E = {
    ...createWiedervorlageItem('WiedervorlageZumWiedereroeffnen'),
    done: true,
  };
  const wiedervorlageAttachedItemZuWiedereroeffnen: VorgangAttachedItemE2E = {
    ...createWiedervorlageAttachedItem(objectIds[1], vorgang._id.$oid),
    item: wiedervorlageZumWiedereroeffnen,
  };

  before(() => {
    initVorgang(vorgang);
    initVorgangAttachedItem([
      wiedervorlageAttachedItemZumErledigen,
      wiedervorlageAttachedItemZuWiedereroeffnen,
    ]);

    loginAsSabine();

    waitForSpinnerToDisappear();
    exist(mainPage.getVorgangList().getRoot());
  });

  after(() => {
    dropCollections();
  });

  describe('Open Vorgang-Detail-Page', () => {
    it('Open Vorgang-Detail-Page', () => {
      mainPage.getVorgangList().getListItem(vorgang.name).getRoot().click();

      waitforSpinnerToAppear();
      waitForSpinnerToDisappear();

      exist(vorgangPage.getVorgangDetailHeader().getRoot());
    });
  });

  describe('erledigen', () => {
    const wiedervorlage: WiedervorlageInVorgangE2EComponent =
      wiedervorlageContainerInVorgang.getWiedervorlage(wiedervorlageZumErledigen.betreff);

    it('should open wiedervorlage on click', () => {
      exist(wiedervorlage.getRoot());

      wait(500);
      wiedervorlage.getLink().click();
      waitForSpinnerToDisappear();

      exist(subnavigation.getRoot());
    });

    it('should mark as erledigt after do erledigen', () => {
      subnavigation.erledigen();

      waitforSpinnerToAppear();
      waitForSpinnerToDisappear();

      wait(1000, 'Wait for async BE to complete');

      containClass(wiedervorlageContainer.getStatusDot(), 'erledigt');
      contains(
        snackBar.getMessage(),
        `Die Wiedervorlage ${wiedervorlageZumErledigen.betreff} wurde erledigt`,
      );
    });

    it('should close snackBar on close', () => {
      snackBar.getCloseButton().click();

      notExist(snackBar.getMessage());
    });

    it('should open vorgang detail on click on back', () => {
      subnavigation.navigateBack();

      waitforSpinnerToAppear();
      waitForSpinnerToDisappear();

      exist(vorgangDetailHeader.getRoot());
    });
  });

  describe('wiedereroeffnen', () => {
    const wiedervorlage: WiedervorlageInVorgangE2EComponent =
      wiedervorlageContainerInVorgang.getWiedervorlage(wiedervorlageZumWiedereroeffnen.betreff);

    it('should open wiedervorlage on click', () => {
      wait(500);
      wiedervorlage.getLink().click();
      waitForSpinnerToDisappear();

      exist(subnavigation.getRoot());
    });

    it('should mark as open after do wiedereroeffnen', () => {
      subnavigation.wiedereroeffnen();

      waitforSpinnerToAppear();
      waitForSpinnerToDisappear();

      wait(1000, 'Wait for async BE to complete');

      notContainClass(wiedervorlageContainer.getStatusDot(), 'erledigt');
      contains(
        snackBar.getMessage(),
        `Die Wiedervorlage ${wiedervorlageZumWiedereroeffnen.betreff} wurde wiedereröffnet`,
      );
    });

    it('should close snackBar on close', () => {
      snackBar.getCloseButton().click();

      notExist(snackBar.getMessage());
    });

    it('should open vorgang detail on click on back', () => {
      subnavigation.navigateBack();

      waitforSpinnerToAppear();
      waitForSpinnerToDisappear();

      exist(vorgangDetailHeader.getRoot());
    });
  });

  describe('View Wiedervorlage view icon', () => {
    const wiedervorlage: WiedervorlageInVorgangE2EComponent =
      wiedervorlageContainerInVorgang.getWiedervorlage(wiedervorlageZumWiedereroeffnen.betreff);
    const locatorIconIsOverdue: string = 'wiedervorlage-icon-is-overdue';
    const locatorIconDefault: string = 'wiedervorlage-icon-default';

    it('back to vorgang list', () => {
      wait(1000, 'Wait for async BE to complete');
      vorgangPage.getSubnavigation().getBackButton().click();
      waitForSpinnerToDisappear();
    });

    it('should show red icon', () => {
      exist(wiedervorlagenView.getRoot().findTestElementWithClass(locatorIconIsOverdue));
    });

    it('Open Vorgang-Detail-Page', () => {
      mainPage.getVorgangList().getListItem(vorgang.name).getRoot().click();
      waitForSpinnerToDisappear();
    });

    it('should mark as erledigt', () => {
      const link = wiedervorlage.getLink();
      link.click();
      waitForSpinnerToDisappear();
      subnavigation.erledigen();
      waitForSpinnerToDisappear();

      wait(1000, 'Wait for async BE to complete');

      subnavigation.navigateBack();
      waitForSpinnerToDisappear();
    });

    it('back to vorgang list', () => {
      vorgangPage.getSubnavigation().getBackButton().click();
      waitForSpinnerToDisappear();
    });

    it('should show default icon', () => {
      exist(wiedervorlagenView.getRoot().findTestElementWithClass(locatorIconDefault));
    });
  });

  describe('tiny lasttest for erledigen/wiedereroeffnen', () => {
    const wiedervorlage: WiedervorlageInVorgangE2EComponent =
      wiedervorlageContainerInVorgang.getWiedervorlage(wiedervorlageZumWiedereroeffnen.betreff);

    it('Open Vorgang-Detail-Page', () => {
      mainPage.getVorgangList().getListItem(vorgang.name).getRoot().click();
      waitForSpinnerToDisappear();
    });

    it('should open wiedervorlage on click', () => {
      wait(500);
      wiedervorlage.getLink().click();

      waitForSpinnerToDisappear();

      exist(subnavigation.getRoot());
    });

    it('should mark as open', () => {
      subnavigation.wiedereroeffnen();

      waitforSpinnerToAppear();
      waitForSpinnerToDisappear();

      notContainClass(wiedervorlageContainer.getStatusDot(), 'erledigt');
      contains(
        snackBar.getMessage(),
        `Die Wiedervorlage ${wiedervorlageZumWiedereroeffnen.betreff} wurde wiedereröffnet`,
      );
    });

    it('should close snackBar on close', () => {
      snackBar.getCloseButton().click();

      notExist(snackBar.getMessage());
    });

    it('should mark as erledigt', () => {
      subnavigation.erledigen();

      waitforSpinnerToAppear();
      waitForSpinnerToDisappear();

      containClass(wiedervorlageContainer.getStatusDot(), 'erledigt');
      contains(
        snackBar.getMessage(),
        `Die Wiedervorlage ${wiedervorlageZumWiedereroeffnen.betreff} wurde erledigt`,
      );
    });

    it('should close snackBar on close', () => {
      snackBar.getCloseButton().click();

      notExist(snackBar.getMessage());
    });

    it('should mark as open', () => {
      subnavigation.wiedereroeffnen();

      waitforSpinnerToAppear();
      waitForSpinnerToDisappear();

      notContainClass(wiedervorlageContainer.getStatusDot(), 'erledigt');
      contains(
        snackBar.getMessage(),
        `Die Wiedervorlage ${wiedervorlageZumWiedereroeffnen.betreff} wurde wiedereröffnet`,
      );
    });

    it('should close snackBar on close', () => {
      snackBar.getCloseButton().click();

      notExist(snackBar.getMessage());
    });

    it('should mark as erledigt', () => {
      subnavigation.erledigen();

      waitforSpinnerToAppear();
      waitForSpinnerToDisappear();

      containClass(wiedervorlageContainer.getStatusDot(), 'erledigt');
      contains(
        snackBar.getMessage(),
        `Die Wiedervorlage ${wiedervorlageZumWiedereroeffnen.betreff} wurde erledigt`,
      );
    });

    it('should close snackBar on close', () => {
      snackBar.getCloseButton().click();

      notExist(snackBar.getMessage());
    });

    it('should open vorgang detail on click on back', () => {
      subnavigation.navigateBack();

      waitforSpinnerToAppear();
      waitForSpinnerToDisappear();

      exist(vorgangDetailHeader.getRoot());
    });
  });
});
