/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
import {
  ListResourceServiceConfig,
  ResourceListService,
  ResourceRepository,
} from '@alfa-client/tech-shared';
import { Resource } from '@ngxp/rest';
import { SettingListLinkRel } from './admin-settings.linkrel';
import { SettingItemResource, SettingListResource } from './admin-settings.model';
import { ConfigurationLinkRel } from './configuration/configuration.linkrel';
import { ConfigurationResource } from './configuration/configuration.model';
import { ConfigurationService } from './configuration/configuration.service';

export class SettingListResourceService extends ResourceListService<
  Resource,
  SettingListResource,
  SettingItemResource
> {}

export function createSettingListResourceService(
  repository: ResourceRepository,
  configurationService: ConfigurationService,
) {
  return new ResourceListService(buildConfig(configurationService), repository);
}
function buildConfig(
  configurationService: ConfigurationService,
): ListResourceServiceConfig<ConfigurationResource> {
  return {
    baseResource: configurationService.get(),
    createLinkRel: SettingListLinkRel.CREATE,
    listLinkRel: ConfigurationLinkRel.SETTING,
    listResourceListLinkRel: SettingListLinkRel.LIST,
  };
}
