/*
 * Copyright (C) 2023 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
import { ApiError, ApiErrorAction, createStateResource } from '@alfa-client/tech-shared';
import { createApiRootResource } from 'libs/api-root-shared/test/api-root';
import { createApiError } from 'libs/tech-shared/test/error';
import { ApiRootResource } from '../api-root.model';
import { ApiRootProps } from './api-root.actions';
import { ApiRootState, initialState, reducer } from './api-root.reducer';

import * as ApiRootActions from './api-root.actions';

describe('ApiRoot Reducer', () => {
  describe('on loadHistorie action', () => {
    it('should set loading to true', () => {
      const action = ApiRootActions.loadApiRoot();

      const result: ApiRootState = reducer(initialState, action);

      expect(result.apiRoot.loading).toBeTruthy();
    });
  });

  describe('on loadApiRootSuccess action', () => {
    it('should set loaded resource into state', () => {
      const apiRoot: ApiRootResource = createApiRootResource();
      const action = ApiRootActions.loadApiRootSuccess(<ApiRootProps>{ apiRoot });

      const result: ApiRootState = reducer(initialState, action);

      expect(result.apiRoot).toEqual(createStateResource(apiRoot));
    });
  });

  describe('on loadApiRootFailure action', () => {
    it('should set error into state', () => {
      const apiError: ApiError = createApiError();
      const action = ApiRootActions.loadApiRootFailure(<ApiErrorAction>{ apiError });

      const result: ApiRootState = reducer(initialState, action);

      expect(result.apiRoot.error).toBe(apiError);
    });
  });
});
