/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
import { createStateResource, StateResource } from '@alfa-client/tech-shared';
import { faker } from '@faker-js/faker';
import { toResource } from 'libs/tech-shared/test/resource';
import { times } from 'lodash-es';
import { createApiError } from '../../../tech-shared/test/error';
import { BescheidListLinkRel } from '../lib/bescheid.linkrel';
import {
  Bescheid,
  BescheidListResource,
  BescheidResource,
  BescheidSendBy,
  BescheidStatus,
  UploadFileInProgress,
} from '../lib/bescheid.model';

export function createBescheid(): Bescheid {
  return {
    status: BescheidStatus.DRAFT,
    beschiedenAm: '2024-01-01',
    bewilligt: true,
    bescheidDocument: faker.internet.url(),
    attachments: [faker.internet.url(), faker.internet.url()],
    sendBy: BescheidSendBy.NACHRICHT,
    nachrichtSubject: faker.lorem.text(),
    nachrichtText: faker.lorem.text(),
  };
}

export function createBescheidResource(linkRel: string[] = []): BescheidResource {
  return toResource(createBescheid(), linkRel);
}

export function createBescheidStateResource(
  linkRel: string[] = [],
): StateResource<BescheidResource> {
  return createStateResource(createBescheidResource(linkRel));
}

export function createUploadFileInProgress(): UploadFileInProgress {
  return { loading: true, fileName: faker.person.firstName(), error: createApiError() };
}

export function createBescheidResources(linkRelations: string[] = []): BescheidResource[] {
  return times(10, () => toResource(createBescheidResource(), [...linkRelations]));
}

export function createBescheidListResource(
  bescheide: BescheidResource[] = createBescheidResources(),
  linkRelations: string[] = [],
): BescheidListResource {
  return toResource({}, [...linkRelations], {
    [BescheidListLinkRel.BESCHEID_LIST]: bescheide,
  });
}
