/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
import { BescheidWizardStep } from '@alfa-client/bescheid-shared';
import { ComponentFixture, TestBed } from '@angular/core/testing';
import { BescheidWizardStepComponent } from './bescheid-wizard-step.component';

describe('BescheidWizardStepComponent', () => {
  let component: BescheidWizardStepComponent;
  let fixture: ComponentFixture<BescheidWizardStepComponent>;

  beforeEach(async () => {
    await TestBed.configureTestingModule({
      declarations: [BescheidWizardStepComponent],
    }).compileComponents();

    fixture = TestBed.createComponent(BescheidWizardStepComponent);
    component = fixture.componentInstance;
    fixture.detectChanges();
  });

  it('should create', () => {
    expect(component).toBeTruthy();
  });

  describe('isActive', () => {
    beforeEach(() => {
      component.activeStep = BescheidWizardStep.DokumenteHochladen;
    });

    it('return true if step equals activeStep', () => {
      component.step = BescheidWizardStep.DokumenteHochladen;

      const isActive: boolean = component.isActive();

      expect(isActive).toBeTruthy();
    });

    it('return false if step not equals activeStep', () => {
      component.step = BescheidWizardStep.AntragBescheiden;

      const isActive: boolean = component.isActive();

      expect(isActive).toBeFalsy();
    });
  });

  describe('isPrevious', () => {
    beforeEach(() => {
      component.activeStep = BescheidWizardStep.DokumenteHochladen;
    });

    it('return true if step is less than activeStep', () => {
      component.step = BescheidWizardStep.AntragBescheiden;

      const isPrevious: boolean = component.isPrevious();

      expect(isPrevious).toBeTruthy();
    });

    it('return false if step equals activeStep', () => {
      component.step = BescheidWizardStep.DokumenteHochladen;

      const isPrevious: boolean = component.isPrevious();

      expect(isPrevious).toBeFalsy();
    });

    it('return false if step is greater than activeStep', () => {
      component.step = BescheidWizardStep.BescheidVersenden;

      const isPrevious: boolean = component.isPrevious();

      expect(isPrevious).toBeFalsy();
    });
  });

  describe('isNext', () => {
    beforeEach(() => {
      component.activeStep = BescheidWizardStep.DokumenteHochladen;
    });

    it('return false if step is less than activeStep', () => {
      component.step = BescheidWizardStep.AntragBescheiden;

      const isNext: boolean = component.isNext();

      expect(isNext).toBeFalsy();
    });

    it('return false if step equals activeStep', () => {
      component.step = BescheidWizardStep.DokumenteHochladen;

      const isNext: boolean = component.isNext();

      expect(isNext).toBeFalsy();
    });

    it('return true if step is greater than activeStep', () => {
      component.step = BescheidWizardStep.BescheidVersenden;

      const isNext: boolean = component.isNext();

      expect(isNext).toBeTruthy();
    });
  });

  describe('clickHandler', () => {
    beforeEach(() => {
      component.stepChange.emit = jest.fn();
    });

    it('should emit step', () => {
      component.isPrevious = jest.fn().mockReturnValue(true);

      component.clickHandler(BescheidWizardStep.AntragBescheiden);

      expect(component.stepChange.emit).toHaveBeenCalledWith(BescheidWizardStep.AntragBescheiden);
    });

    it('should not emit step', () => {
      component.isPrevious = jest.fn().mockReturnValue(false);

      component.clickHandler(BescheidWizardStep.AntragBescheiden);

      expect(component.stepChange.emit).not.toHaveBeenCalled();
    });
  });
});
