/*
 * Copyright (C) 2023 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
import { ComponentFixture, TestBed } from '@angular/core/testing';
import { LoeschAnforderungService } from '@alfa-client/loesch-anforderung-shared';
import { HasLinkPipe } from '@alfa-client/tech-shared';
import { Mock, mock } from '@alfa-client/test-utils';
import { VorgangWithEingangResource } from '@alfa-client/vorgang-shared';
import { createVorgangWithEingangResource } from 'libs/vorgang-shared/test/vorgang';
import { MockComponent } from 'ng-mocks';
import { LoeschenAnfordernButtonContainerComponent } from './loeschen-anfordern-button-container.component';
import { LoeschenAnfordernButtonComponent } from './loeschen-anfordern-button/loeschen-anfordern-button.component';

describe('LoeschenAnfordernButtonContainerComponent', () => {
  let component: LoeschenAnfordernButtonContainerComponent;
  let fixture: ComponentFixture<LoeschenAnfordernButtonContainerComponent>;

  const vorgangWithEingang: VorgangWithEingangResource = createVorgangWithEingangResource();

  const service: Mock<LoeschAnforderungService> = mock(LoeschAnforderungService);

  beforeEach(async () => {
    await TestBed.configureTestingModule({
      declarations: [
        LoeschenAnfordernButtonContainerComponent,
        HasLinkPipe,
        MockComponent(LoeschenAnfordernButtonComponent),
      ],
      providers: [
        {
          provide: LoeschAnforderungService,
          useValue: service,
        },
      ],
    }).compileComponents();

    fixture = TestBed.createComponent(LoeschenAnfordernButtonContainerComponent);
    component = fixture.componentInstance;
    component.vorgang = vorgangWithEingang;
    fixture.detectChanges();
  });

  it('should create', () => {
    expect(component).toBeTruthy();
  });

  describe('ngOnInit', () => {
    it('should call service', () => {
      component.ngOnInit();

      expect(service.getLoeschenAnfordernCommand).toHaveBeenCalled();
    });
  });

  describe('loeschenAnfordern', () => {
    it('should call service', () => {
      component.loeschenAnfordern();

      expect(service.loeschenAnfordern).toHaveBeenCalledWith(vorgangWithEingang);
    });
  });
});
