/*
 * Copyright (C) 2023 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
import { createStateResource } from '@alfa-client/tech-shared';
import { UserProfileResource } from '@alfa-client/user-profile-shared';
import { ComponentFixture, TestBed } from '@angular/core/testing';
import { MatTooltipModule } from '@angular/material/tooltip';
import { createUserProfileResource } from 'libs/user-profile-shared/test/user-profile';
import { MockModule } from 'ng-mocks';
import { TextWithUserNameTooltipComponent } from './text-with-user-name-tooltip.component';

describe('TextWithUserNameTooltipComponent', () => {
  let component: TextWithUserNameTooltipComponent;
  let fixture: ComponentFixture<TextWithUserNameTooltipComponent>;

  const userProfile: UserProfileResource = createUserProfileResource();
  const tooltipTemplate: string = 'TooltipTemplate with placeholder {firstName} {lastName}';

  beforeEach(async () => {
    await TestBed.configureTestingModule({
      declarations: [TextWithUserNameTooltipComponent, MockModule(MatTooltipModule)],
    }).compileComponents();
  });

  beforeEach(() => {
    fixture = TestBed.createComponent(TextWithUserNameTooltipComponent);
    component = fixture.componentInstance;
    component.tooltipTemplate = tooltipTemplate;
    fixture.detectChanges();
  });

  it('should create', () => {
    expect(component).toBeTruthy();
  });

  describe('ngOnInit', () => {
    it('should build tooltip with empty userProfile', () => {
      component.ngOnInit();

      expect(component.tooltip).toEqual('TooltipTemplate with placeholder undefined undefined');
    });
  });

  describe('tooltip', () => {
    it('should be build with replaced placefolders', () => {
      component.tooltipTemplate = tooltipTemplate;
      component.userProfile = createStateResource(userProfile);
      fixture.detectChanges();

      component.ngOnInit();

      expect(component.tooltip).toBe(
        `TooltipTemplate with placeholder ${userProfile.firstName} ${userProfile.lastName}`,
      );
    });
  });
});
