/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
import { isNotNull } from '@alfa-client/tech-shared';
import {
  ExterneFachstelleResource,
  ExterneFachstelleService,
  ZUSTAENDIGE_STELLE_SERVICE,
  ZustaendigeStelleService,
} from '@alfa-client/zustaendige-stelle-shared';
import { Component, Inject, Input, OnDestroy, OnInit } from '@angular/core';
import { AbstractControl } from '@angular/forms';
import { ResourceUri, getUrl } from '@ngxp/rest';
import { Observable, tap } from 'rxjs';

@Component({
  selector: 'alfa-search-externe-fachstelle-container',
  templateUrl: './search-externe-fachstelle-container.component.html',
  providers: [{ provide: ZUSTAENDIGE_STELLE_SERVICE, useClass: ExterneFachstelleService }],
})
export class SearchExterneFachstelleContainerComponent implements OnInit, OnDestroy {
  @Input() public fieldControl: AbstractControl<ResourceUri>;

  public externeFachstelleResource$: Observable<ExterneFachstelleResource>;

  constructor(
    @Inject(ZUSTAENDIGE_STELLE_SERVICE)
    private service: ZustaendigeStelleService<ExterneFachstelleResource>,
  ) {}

  ngOnInit(): void {
    this.externeFachstelleResource$ = this.getSelectedResult();
  }

  ngOnDestroy(): void {
    this.service.clearSelectedResult();
  }

  getSelectedResult(): Observable<ExterneFachstelleResource> {
    return this.service
      .getSelectedResult()
      .pipe(tap((externeFachstelleResource: ExterneFachstelleResource) => this.handleResult(externeFachstelleResource)));
  }

  handleResult(externeFachstelleResource: ExterneFachstelleResource): void {
    if (isNotNull(externeFachstelleResource)) {
      this.fieldControl.patchValue(getUrl(externeFachstelleResource));
    }
  }
}
