/*
 * Copyright (C) 2023 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.alfa.common.binaryfile;

import java.util.concurrent.CompletableFuture;

import de.ozgcloud.vorgang.grpc.binaryFile.GrpcUploadBinaryFileRequest;
import de.ozgcloud.vorgang.grpc.binaryFile.GrpcUploadBinaryFileResponse;
import io.grpc.stub.ClientCallStreamObserver;
import io.grpc.stub.ClientResponseObserver;
import lombok.AccessLevel;
import lombok.Getter;
import lombok.RequiredArgsConstructor;

@RequiredArgsConstructor(access = AccessLevel.PROTECTED)
class BinaryFileUploadStreamObserver implements ClientResponseObserver<GrpcUploadBinaryFileRequest, GrpcUploadBinaryFileResponse> {

	private final CompletableFuture<FileId> fileIdFuture;
	private final ChunkedFileSender<GrpcUploadBinaryFileRequest> fileStreamer;

	@Getter
	private String fileId;

	private ClientCallStreamObserver<GrpcUploadBinaryFileRequest> requestObserver;

	@Override
	public void beforeStart(ClientCallStreamObserver<GrpcUploadBinaryFileRequest> requestStream) {
		this.requestObserver = requestStream;
		requestObserver.setOnReadyHandler(() -> fileStreamer.sendChunkTo(requestObserver));
	}

	@Override
	public void onNext(GrpcUploadBinaryFileResponse response) {
		fileId = response.getFileId();
	}

	@Override
	public void onError(Throwable t) {
		fileIdFuture.completeExceptionally(t);
	}

	@Override
	public void onCompleted() {
		fileIdFuture.complete(FileId.from(fileId));
	}
}