/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.alfa.export;

import java.io.IOException;
import java.io.OutputStream;
import java.util.Iterator;

import de.ozgcloud.archive.grpc.export.GrpcExportVorgangResponse;
import de.ozgcloud.common.errorhandling.TechnicalException;
import lombok.Getter;

class StreamedExportedVorgangFile implements ExportedVorgangFile {

	@Getter
	private final String fileName;
	private final Iterator<GrpcExportVorgangResponse> responseIterator;

	public StreamedExportedVorgangFile(Iterator<GrpcExportVorgangResponse> responseIterator) {
		this.fileName = getFileNameFrom(responseIterator);
		this.responseIterator = responseIterator;
	}

	static String getFileNameFrom(Iterator<GrpcExportVorgangResponse> responseIterator) {
		if (!responseIterator.hasNext()) {
			throw new TechnicalException("Response is empty");
		}
		return responseIterator.next().getVorgangFile().getFileName();
	}

	@Override
	public void writeToOutputStream(OutputStream outputStream) throws IOException {
		while (responseIterator.hasNext()) {
			outputStream.write(responseIterator.next().getVorgangFile().getFileContent().toByteArray());
		}
	}
}
