/*
 * Copyright (C) 2023 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.alfa.loeschanforderung;

import org.springframework.stereotype.Component;

import de.ozgcloud.alfa.common.command.CommandOrder;
import de.ozgcloud.alfa.common.user.CurrentUserService;
import de.ozgcloud.alfa.common.user.UserRole;
import lombok.RequiredArgsConstructor;

@Component
@RequiredArgsConstructor
class LoeschAnforderungPreAuthorizeHandler {

	private final LoeschAnforderungService loeschAnforderungService;
	private final CurrentUserService currentUserService;

	public boolean hasPermissionForOrder(String loeschAnforderungId, CommandOrder order) {
		return switch (order) {
			case VORGANG_LOESCHEN -> loeschAnforderungService.isAllowedToVorgangLoeschen(loeschAnforderungService.getById(loeschAnforderungId));
			case LOESCH_ANFORDERUNG_ZURUECKNEHMEN -> hasRoleForZuruecknehmen();
			default -> false;
		};
	}

	private boolean hasRoleForZuruecknehmen() {
		return currentUserService.hasRole(UserRole.VERWALTUNG_USER) || currentUserService.hasRole(UserRole.EINHEITLICHER_ANSPRECHPARTNER);
	}

}
