/*
 * Copyright (C) 2023 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.alfa.common.command;

import static org.assertj.core.api.Assertions.*;
import static org.mockito.Mockito.*;

import jakarta.validation.ConstraintValidatorContext;

import org.junit.jupiter.api.BeforeEach;
import org.junit.jupiter.api.Nested;
import org.junit.jupiter.api.Test;
import org.mockito.Mock;

class RequiredOrderValidatorTest {

	private final RequiredOrderValidator validator = new RequiredOrderValidator();

	@Mock
	private RequiredOrder requiredOrder;

	@Mock
	private ConstraintValidatorContext constraintValidatorContext;

	@Nested
	class TestIsValid {
		private CommandOrder commandOrder = CommandOrder.VORGANG_ANNEHMEN;

		@BeforeEach
		void init() {
			when(requiredOrder.value()).thenReturn(commandOrder);
			validator.initialize(requiredOrder);
		}

		@Test
		void shouldReturnTrue() {
			var validationResult = validator.isValid(CommandTestFactory.createCreateCommandBuilder().order(commandOrder.name()).build(),
					constraintValidatorContext);

			assertThat(validationResult).isTrue();
		}

		@Test
		void shouldReturnFalse() {
			var validationResult = validator.isValid(
					CommandTestFactory.createCreateCommandBuilder().order(CommandOrder.ASSIGN_USER.name()).build(),
					constraintValidatorContext);

			assertThat(validationResult).isFalse();
		}
	}

}