/*
 * Copyright (C) 2023 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.alfa.hint;

import static org.assertj.core.api.Assertions.*;

import java.util.List;

import org.junit.jupiter.api.DisplayName;
import org.junit.jupiter.api.Nested;
import org.junit.jupiter.api.Test;
import org.springframework.hateoas.IanaLinkRelations;
import org.springframework.hateoas.Link;

class HintModelAssemblerTest {

	private HintModelAssembler modelAssembler = new HintModelAssembler();

	@DisplayName("To collectionModel")
	@Nested
	class TestToCollectionModel {

		@Test
		void shouldHaveSelfLink() {
			var collectionModel = modelAssembler.toCollectionModel(List.of(HintTestFactory.create()));

			assertThat(collectionModel.getLink(IanaLinkRelations.SELF)).isPresent()
					.get().extracting(Link::getHref).isEqualTo(HintController.PATH);
		}
	}

	@DisplayName("To model")
	@Nested
	class TestToModel {

		@Test
		void shouldHaveSelfLink() {
			var model = modelAssembler.toModel(HintTestFactory.create());

			assertThat(model.getLink(IanaLinkRelations.SELF)).isPresent().get().extracting(Link::getHref)
					.isEqualTo(String.format("%s/%s", HintController.PATH, HintTestFactory.CODE));
		}
	}
}
