/*
 * Copyright (C) 2023 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.alfa.loeschanforderung;

import static de.ozgcloud.alfa.common.UserProfileUrlProviderTestFactory.*;
import static org.mockito.Mockito.*;
import static org.springframework.test.web.servlet.request.MockMvcRequestBuilders.*;
import static org.springframework.test.web.servlet.result.MockMvcResultMatchers.*;

import org.junit.jupiter.api.BeforeEach;
import org.junit.jupiter.api.Nested;
import org.junit.jupiter.api.Test;
import org.mockito.InjectMocks;
import org.mockito.Mock;
import org.springframework.hateoas.EntityModel;
import org.springframework.test.web.servlet.MockMvc;
import org.springframework.test.web.servlet.ResultActions;
import org.springframework.test.web.servlet.setup.MockMvcBuilders;

import de.ozgcloud.alfa.common.UserProfileUrlProvider;
import de.ozgcloud.alfa.common.errorhandling.ExceptionController;
import de.ozgcloud.alfa.common.errorhandling.ProblemDetailMapper;
import lombok.SneakyThrows;

class LoeschAnforderungControllerTest {

	@InjectMocks
	private LoeschAnforderungController controller;

	@Mock
	private LoeschAnforderungService loeschAnforderungService;

	@Mock
	private LoeschAnforderungModelAssembler modelAssembler;

	@Mock
	private ProblemDetailMapper problemDetailMapper;

	private MockMvc mockMvc;

	@BeforeEach
	void init() {
		mockMvc = MockMvcBuilders.standaloneSetup(controller).setControllerAdvice(new ExceptionController(problemDetailMapper)).build();
	}

	@Nested
	class TestGetLoeschanforderung {

		private final LoeschAnforderung loeschAnforderung = LoeschAnforderungTestFactory.create();

		@BeforeEach
		void init() {
			when(loeschAnforderungService.getById(LoeschAnforderungTestFactory.ID)).thenReturn(loeschAnforderung);
			when(modelAssembler.toModel(loeschAnforderung)).thenReturn(EntityModel.of(loeschAnforderung));
		}

		@Test
		void shouldLoadLoeschAnforderung() {
			doRequest();

			verify(loeschAnforderungService).getById(LoeschAnforderungTestFactory.ID);
		}

		@Test
		void shouldCallModelAssembler() {
			doRequest();

			verify(modelAssembler).toModel(loeschAnforderung);
		}

		@Test
		void shouldReturn200() throws Exception {
			initUserProfileUrlProvider(new UserProfileUrlProvider());

			var response = doRequest();

			response.andExpect(status().isOk());
		}

		@SneakyThrows
		private ResultActions doRequest() {
			return mockMvc.perform(get(LoeschAnforderungController.BASE_PATH + "/" + LoeschAnforderungTestFactory.ID));
		}
	}
}