/*
 * Copyright (C) 2023 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.alfa.loeschanforderung;

import static org.assertj.core.api.Assertions.*;

import java.util.Map;

import org.junit.jupiter.api.DisplayName;
import org.junit.jupiter.api.Nested;
import org.junit.jupiter.api.Test;

import de.ozgcloud.alfa.common.attacheditem.VorgangAttachedItem;
import de.ozgcloud.alfa.common.attacheditem.VorgangAttachedItemTestFactory;
import de.ozgcloud.alfa.common.command.Command;
import de.ozgcloud.alfa.common.command.CommandTestFactory;
import de.ozgcloud.alfa.vorgang.VorgangHeaderTestFactory;

class LoeschAnforderungMapperTest {

	private final LoeschAnforderungMapper mapper = new LoeschAnforderungMapper();

	@DisplayName("From vorgangAttachedItem")
	@Nested
	class TestFromVorgangAttachedItem {

		private final VorgangAttachedItem vorgangAttachedItem = VorgangAttachedItemTestFactory.createBuilder().item(Map.of(
				LoeschAnforderung.REQUESTED_BY_FIELD,
				LoeschAnforderungTestFactory.REQUESTED_BY.toString(),
				LoeschAnforderung.PREV_STATUS_FIELD,
				LoeschAnforderungTestFactory.PREV_STATUS.name())).build();

		@Test
		void shouldMapId() {
			var loeschAnforderung = mapFromVorgangAttachedItem();

			assertThat(loeschAnforderung.getId()).isEqualTo(VorgangAttachedItemTestFactory.ID);
		}

		@Test
		void shouldMapVorgangId() {
			var loeschAnforderung = mapFromVorgangAttachedItem();

			assertThat(loeschAnforderung.getVorgangId()).isEqualTo(VorgangHeaderTestFactory.ID);
		}

		@Test
		void shouldMapRequestBy() {
			var loeschAnforderung = mapFromVorgangAttachedItem();

			assertThat(loeschAnforderung.getRequestedBy()).isEqualTo(LoeschAnforderungTestFactory.REQUESTED_BY);
		}

		@Test
		void shouldMapPrevStatus() {
			var loeschAnforderung = mapFromVorgangAttachedItem();

			assertThat(loeschAnforderung.getPrevStatus()).isEqualTo(LoeschAnforderungTestFactory.PREV_STATUS);
		}

		private LoeschAnforderung mapFromVorgangAttachedItem() {
			return mapper.fromVorgangAttachedItem(vorgangAttachedItem);
		}
	}

	@DisplayName("From Command")
	@Nested
	class TestBuildLoeschAnforderung {

		private final Command command = CommandTestFactory.createBuilder()
				.body(Map.of(VorgangAttachedItem.ITEM_FIELD, LoeschAnforderungTestFactory.asMap()))
				.build();

		@Test
		void shouldHaveId() {
			var loeschAnforderung = mapper.fromCommand(command);

			assertThat(loeschAnforderung.getId()).isEqualTo(CommandTestFactory.RELATION_ID);
		}

		@Test
		void shouldHaveVorgangId() {
			var loeschAnforderung = mapper.fromCommand(command);

			assertThat(loeschAnforderung.getVorgangId()).isEqualTo(VorgangHeaderTestFactory.ID);
		}

		@Test
		void shouldHaveRequestedBy() {
			var loeschAnforderung = mapper.fromCommand(command);

			assertThat(loeschAnforderung.getRequestedBy()).isEqualTo(LoeschAnforderungTestFactory.REQUESTED_BY);
		}

		@Test
		void shouldHavePrevStatus() {
			var loeschAnforderung = mapper.fromCommand(command);

			assertThat(loeschAnforderung.getPrevStatus()).isEqualTo(LoeschAnforderungTestFactory.PREV_STATUS);
		}
	}
}
