/*
 * Copyright (C) 2023 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.alfa.vorgang;

import static org.assertj.core.api.Assertions.*;
import static org.mockito.Mockito.*;

import org.junit.jupiter.api.BeforeEach;
import org.junit.jupiter.api.DisplayName;
import org.junit.jupiter.api.Nested;
import org.junit.jupiter.api.Test;
import org.junit.jupiter.params.ParameterizedTest;
import org.junit.jupiter.params.provider.EnumSource;
import org.mockito.InjectMocks;
import org.mockito.Mock;

import de.ozgcloud.alfa.common.user.CurrentUserService;
import de.ozgcloud.alfa.common.user.UserRole;
import de.ozgcloud.alfa.vorgang.Vorgang.VorgangStatus;

class VorgangAuthorizationServiceTest {

	@InjectMocks
	private VorgangAuthorizationService service;
	@Mock
	private CurrentUserService userService;

	@Nested
	class TestVerifyByUserRole {

		@Nested
		class TestForVerwaltungPoststelle {

			@BeforeEach
			void mockUserRole() {
				when(userService.hasRole(UserRole.VERWALTUNG_POSTSTELLE)).thenReturn(true);
			}

			@DisplayName("should return true by vorgangstatus 'Neu'")
			@Test
			void shouldReturnTrue() {
				var authorized = service.verifyByUserRole(VorgangWithEingangTestFactory.createBuilder().status(VorgangStatus.NEU).build());

				assertThat(authorized).isTrue();
			}

			@DisplayName("should return false by other vorgangstatus then 'Neu'")
			@ParameterizedTest
			@EnumSource(value = VorgangStatus.class, names = { "ANGENOMMEN", "VERWORFEN", "IN_BEARBEITUNG", "BESCHIEDEN", "ABGESCHLOSSEN",
					"WEITERGELEITET" })
			void shouldReturnFalse(VorgangStatus status) {
				var authorized = service.verifyByUserRole(VorgangWithEingangTestFactory.createBuilder().status(status).build());

				assertThat(authorized).isFalse();
			}
		}

		@Nested
		class TestForOtherRoles {

			@BeforeEach
			void mockUserRole() {
				when(userService.hasRole(UserRole.VERWALTUNG_POSTSTELLE)).thenReturn(false);
			}

			@DisplayName("should return true on role 'VERWALTUNG_USER' independent which vorgangstatus")
			@ParameterizedTest
			@EnumSource(value = VorgangStatus.class, names = { "NEU", "ANGENOMMEN", "VERWORFEN", "IN_BEARBEITUNG", "BESCHIEDEN", "ABGESCHLOSSEN",
					"WEITERGELEITET" })
			void shouldReturnTrue(VorgangStatus status) {
				var authorized = service.verifyByUserRole(VorgangWithEingangTestFactory.createBuilder().status(status).build());

				assertThat(authorized).isTrue();
			}
		}
	}
}